@@ -29,7 +29,7 @@ class AdminInvoices(admin.ModelAdmin):
               )
 
     def get_PDF(self, obj):
-        return '<a href="/rinvoices/PDF/%s/es">PDFes</a>, <a href="/rinvoices/PDF/%s/en">PDFen</a>, <a href="/rinvoices/txtPDF/%s/es">TXTes</a>, <a href="/rinvoices/txtPDF/%s/en">TXTen</a>' % (str(obj.invoice_number), str(obj.invoice_number), str(obj.invoice_number), str(obj.invoice_number))
+        return '<a href="/rinvoices/PDF/%s/es">PDFes</a>, <a href="/rinvoices/PDF/%s/en">PDFen</a>, <a href="/rinvoices/txtPDF/%s/es">TXTes</a>, <a href="/rinvoices/txtPDF/%s/en">TXTen</a>' % (str(obj.id), str(obj.id), str(obj.id), str(obj.id))
     get_PDF.allow_tags = True
 
     def save_model(self, request, obj, form, change):
